Tutorial
========

Writing HGraph code can be different to standard procedural coding. This tutorial attempts to help guide the user
through the basics of writing graph code. This tutorial assume you have installed HGraph, if you need to do this refer
to :doc:`../getting_started`.

.. toctree::
    basic_program_structure
    unit_testing
    the_compute_node
    injectables
    typing
    generics
    operators
    graph

    common_pitfalls


